# Package Schemas

Schemas and interfaces describing python packages

[![PyPI](https://img.shields.io/pypi/v/package-schemes)](https://pypi.org/project/package-schemes/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/package-schemes)](https://pypi.org/project/package-schemes/)

[![Downloads](https://static.pepy.tech/badge/package-schemes)](https://pepy.tech/project/package-schemes)
[![GitLab stars](https://img.shields.io/gitlab/stars/rocshers/python/package-schemes)](https://gitlab.com/rocshers/python/package-schemes)
[![GitLab last commit](https://img.shields.io/gitlab/last-commit/rocshers/python/package-schemes)](https://gitlab.com/rocshers/python/package-schemes)

## Content

- [Package Schemas](#package-schemas)
  - [Content](#content)
  - [Schemes](#schemes)
    - [package\_schemes.PyProjectScheme](#package_schemespyprojectscheme)
    - [package\_schemes.UvLockV1Scheme](#package_schemesuvlockv1scheme)
  - [Contribute](#contribute)

## Schemes

### package_schemes.PyProjectScheme

### package_schemes.UvLockV1Scheme

## Contribute

Issue Tracker: <https://gitlab.com/rocshers/python/package-schemes/-/issues>  
Source Code: <https://gitlab.com/rocshers/python/package-schemes>

Before adding changes:

```bash
make install
```

After changes:

```bash
make format test
```
